const activeEnv = process.env.GATSBY_ACTIVE_ENV || 'development';
const sitemapNewsExclude = process.env.SITEMAP_EXCLUDE.split(',') || [];

// eslint-disable-next-line import/no-extraneous-dependencies
require('dotenv').config({
  path: `.env.${activeEnv}`,
});

module.exports = {
  flags: {
    DEV_SSR: false,
  },
  plugins: [
    {
      resolve: `gatsby-core-theme`,
      options: {
        siteName: process.env.GATSBY_SITE_NAME,
        preconnectLinks: [process.env.IMAGE_CDN_URL],
      },
    },
    {
      resolve: `gatsby-plugin-sitemap`,
      options: {
        output: `/sitemap-news.xml`,
        query: `{
          site {
            siteMetadata {
              siteUrl
            }
          }
          allSitePage {
            nodes {
              path,
              pageContext
            }
          }
        }`,
        exclude: sitemapNewsExclude,
        serialize: ({ site, allSitePage }) =>
          allSitePage.nodes.map((edge) => ({
            url: site.siteMetadata.siteUrl + edge.path,
            news: {
              publication: {
                name:
                  edge.pageContext.page &&
                  edge.pageContext.page.title &&
                  edge.pageContext.page.title.replace(/[^\w\s]/gi, ''),
                language: edge.pageContext.page && edge.pageContext.page.language,
              },
              publication_date: edge.pageContext.page && edge.pageContext.page.updated_at,
              title:
                edge.pageContext.page &&
                edge.pageContext.page.meta_title &&
                edge.pageContext.page.meta_title.replace(/[^\w\s]/gi, ''),
            },
          })),
      },
    },
    `gatsby-plugin-image`,
    `gatsby-plugin-sharp`,
    `gatsby-transformer-sharp`,
  ],
};
