/* eslint-disable react/prop-types */
import React from 'react';
import { useContext, useEffect, useState } from 'react';
import PropTypes from 'prop-types';
import { scoreTabs, amTabs } from 'sports-util/dist/constants';
import { buildRows, getSportColumns, sortByTabs } from '../../../helpers/standings';
import Tabs from '~hooks/tabs';
import styles from './standings.module.scss';

export default function Standings({ serverData }) {
  const { standings } = serverData;
  const sportName = 'football';
  const tabs = scoreTabs;
  const [columns, setColumns] = useState([]);
  const [rows, setRows] = useState([]);

  function handleOnClick(tab) {
    setTabActive(tab);
  }

  useEffect(() => {
    if (standings) {
      const dataTable = [];
      const dataHedings = [];

      tabs.map((type) => {
        const filteredColumns = getSportColumns(sportName, type);
        const filteredRows = buildRows(
          sortByTabs(standings, type, sportName),
          filteredColumns,
          type
        );

        dataHedings.push(filteredColumns);
        setColumns(dataHedings);
        dataTable.push(filteredRows);
        setRows(dataTable);
      });
    }
  }, [standings]);

  return (
    columns.length > 0 && (
      <Tabs tabsAlign="left">
        {tabs.map((tab, index) => (
          <div label={tab}>
            <table className={styles.standingsTable}>
              <thead>
                <tr>
                  {columns[index].map((column) => (
                    <th>{column.label}</th>
                  ))}
                </tr>
              </thead>
              <tbody>
                {rows[index].map((row, idx) => (
                  // eslint-disable-next-line react/no-array-index-key
                  <tr key={idx}>{row}</tr>
                ))}
              </tbody>
            </table>
          </div>
        ))}
      </Tabs>
    )
  );
}

Standings.propTypes = {
  id: PropTypes.string,
  mockData: PropTypes.shape({}),
};
