/* eslint-disable react/prop-types */
/* eslint-disable no-shadow */
import React, { useContext } from 'react';
import Bonus from '~atoms/bonus';
import { Context } from '~context/MainProvider';
import StarRating from '~molecules/star-rating/one-star';
import Link from '~hooks/link';
import OperatorCta from '~atoms/operator-cta';
import { prettyTracker, imagePrettyUrl, translate, getAltText } from '~helpers/getters';
import LazyImage from '~hooks/lazy-image';
import styles from './top-row.module.scss';

export default function TopRow({
  item,
  oneliner = 'main',
  layout = 'list',
  tracker = 'main',
  pageTemplate,
  itemRefs,
  index,
  className,
}) {
  const prettyLink = prettyTracker(item, 'main', false, pageTemplate);
  const itemRating = item.rating;
  const { translations } = useContext(Context) || {};
  const reviewPath = item.review_link ? `/${item.review_link}` : item.path || '/';
  const imageObject = item?.standardised_logo_url_object || item?.logo_url_object;

  const addToRefs = (el, itemNum) => {
    if (el && itemRefs) {
      itemRefs.current[itemNum] = el;
    }
  };

  return (
    <li
      className={`${className || ''} ${styles.row} ${styles[layout]}`}
      ref={(el) => addToRefs(el, index)}
    >
      <div className={styles.topsection}>
        <a
          href={prettyLink}
          title={item.name}
          className={`casinos-top-list-gtm logo-cta ${styles.logo}`}
          target="_blank"
          rel="noreferrer"
          aria-label={`${item.name} Link`}
        >
          <LazyImage
            alt={getAltText(imageObject, item.name)}
            src={imagePrettyUrl(imageObject?.filename || item?.logo_url, 88, 88)}
            width={88}
            height={88}
          />
        </a>
      </div>
      <div className={styles.bottomsection}>
        <div>
          <p>{item.name}</p>
          <StarRating numOfStars={5} rating={itemRating} />
        </div>
        <div className={styles.oneliner}>
          <Bonus item={item} tracker={oneliner} />
          <OperatorCta
            operator={item}
            tracker={tracker}
            gtmClass="toplist-operator-cta-gtm"
            pageTemplate={pageTemplate}
          />
        </div>
        <Link className={`${styles.reviewLink} toplist-variant-one-gtm`} to={reviewPath}>
          {`${translate(translations, 'read_review', 'Review')}`}
        </Link>
      </div>
    </li>
  );
}
